# Changelog

## [0.2.0](https://github.com/CoreySpohn/exoverses/compare/v0.1.1...v0.2.0) (2024-04-03)


### Features

* **main:** Add Kopparapu bins based on EXOSIMS implementation ([d49dd76](https://github.com/CoreySpohn/exoverses/commit/d49dd763af9c73d13e1dd7387a0940abc9976f15))


### Bug Fixes

* cleaning up target list to remove duplicate HIP values to match the stars in the large ExoVista target list ([cb4106f](https://github.com/CoreySpohn/exoverses/commit/cb4106fd3f7c2793b25c01e32190aa27ee749b70))
* fixing formatting of the util init file for importing ([2067963](https://github.com/CoreySpohn/exoverses/commit/206796310d98e7f28207dc0c39abed23595abcde))
* incorrect import statement in the util ([0c5460a](https://github.com/CoreySpohn/exoverses/commit/0c5460a506a0e2bf3b7791625a06e5259ef7cddc))
* **main:** Added system name property ([592edc2](https://github.com/CoreySpohn/exoverses/commit/592edc20f93f0021538738994afe46cb28da2c73))
